//
// Designed by Jan Uhrin, OM2JU, free to copy, modify
// Xmas gift for memebrs of OM3KII radioclub, 2022
//

$fn = 32;  // set to lower value when designing, higher, e.g. 32 when generating STL

$label = "kii";  // keep the label short = 3-4 letters or simply define as empty = ""

// Libraries:
//----------------------------------------------------------------------------------
//
// Rounded primitives for openscad
// (c) 2013 Wouter Robers 

// Syntax example for a rounded block
//translate([-15,0,10]) rcube([20,20,20],2);

// Syntax example for a rounded cylinder
//translate([15,0,10]) rcylinder(r1=15,r2=10,h=20,b=2);

module rcube(Size=[20,20,20],b=2)
{hull(){for(x=[-(Size[0]/2-b),(Size[0]/2-b)]){for(y=[-(Size[1]/2-b),(Size[1]/2-b)]){for(z=[-(Size[2]/2-b),(Size[2]/2-b)]){ translate([x,y,z]) sphere(b);}}}}}


module rcylinder(r1=10,r2=10,h=10,b=2)
{translate([0,0,-h/2]) hull(){rotate_extrude() translate([r1-b,b,0]) circle(r = b); rotate_extrude() translate([r2-b, h-b, 0]) circle(r = b);}}

//----------------------------------------------------------------------------------

// Inner rounded box dimensions
$box_len = 51;
$box_wid = 28;
$box_hei = 11;

// Outer oval dimensions
$winder_len = 68;
$winder_wid = 41;
$winder_hei = 2.0;

// Oval shaped disc with openings
// Standalone version is used for middle separator part
// version with inner rounded boxes is used as upper or lower part
module disc (disc_hei, label1, label2) {
difference () {
union () {
//
// Oval shaped disc is composed of circle + middle part + circle -->    o[]o
//
// middle part of disc
translate([0,0,disc_hei/2])
rcube(Size = [$winder_wid,$winder_len,disc_hei], b=disc_hei/2.2);

// rounded end-1
translate([$winder_wid/2,0,disc_hei/2])
rcylinder(h=disc_hei, r1 = $winder_len/2, r2 = $winder_len/2, b=disc_hei/2.2);
// rounded end-2
translate([-$winder_wid/2,0,disc_hei/2])
rcylinder(h=disc_hei, r1 = $winder_len/2, r2 = $winder_len/2, b=disc_hei/2.2);

} // end union

// Diameters of holes
$wd=16.4;
$we=16.4;
//
// round holes
translate([-$winder_wid-1.0,0,0])  cylinder(h=10, r1=$wd/2, r2=$wd/2, center = true);
translate([-$winder_wid+7.6,$winder_len/4,0]) cylinder(h=10, r1=$we/2, r2=$we/2, center = true);
translate([-$winder_wid+7.6,-$winder_len/4,0]) cylinder(h=10,r1=$we/2, r2=$we/2, center = true);

// round holes
translate([$winder_wid+1.0,0,0])  cylinder(h=10, r1=$wd/2, r2=$wd/2, center = true);
translate([$winder_wid-7.6,$winder_len/4,0]) cylinder(h=10, r1=$we/2, r2=$we/2, center = true);
translate([$winder_wid-7.6,-$winder_len/4,0]) cylinder(h=10,r1=$we/2, r2=$we/2, center = true);

// label1
rotate([0,180,0])
translate([ -17.4,16.4,0.0]) linear_extrude (height=10, center = true) text(label1, size=14, font="Courier:style=Bold");

// label2
rotate([0,180,180])
translate([ -17.4,16.4,0.0]) linear_extrude (height=10, center = true) text(label2, size=14, font="Courier:style=Bold");


// side cut-1
if (label1 == "") {
 translate([0,$box_wid/1.22,$box_hei/2])
    rcube(Size = [$box_len-10.2,$box_wid/2.3,3*$box_hei], b=2);
}
// side cut-2
if (label2 == "") {
translate([0,-$box_wid/1.22,$box_hei/2])
 rcube(Size = [$box_len-10.2,$box_wid/2.3,3*$box_hei], b=2);
}

translate([0,0,-5+disc_hei-0.4]) cylinder(h=10, r1=30/2, r2=8/2, center = true);

} // end difference


} // end module disc


module tiny_winder_side_A () {

difference () {
  translate([0,0,$box_hei/2])
  rcube(Size = [$box_len,$box_wid,3*$box_hei], b=10);

  translate([0,0,$box_hei/4])
  rcube(Size = [$box_len-6,$box_wid-6,3*$box_hei], b=10);

  // cutout
  translate([0,0,$box_hei/2+7.2])
  rcube(Size = [$box_len-3,$box_wid-3,3*$box_hei], b=10);

  // limit from the bottom
  translate([0,0,-$box_hei/2])
  cube(size=[2*$box_len,2*$box_wid,$box_hei], center=true);

  translate([0,0,$box_hei+$box_hei/2])
  cube(size=[2*$box_len,2*$box_wid,$box_hei], center=true);

  translate([0,0,$box_hei-2])
    rotate([0,90,0])
      cylinder(h=100, r1=1.8/2, r2=1.8/2, center = true);

  translate([0,0,$box_hei-2])
    rotate([90,90,0])
      cylinder(h=100, r1=1.8/2, r2=1.8/2, center = true);

  // Opening for Wire
  translate([-$box_len/2,+3,$box_hei-$winder_hei-2+10])
    rotate([0,90,0])
      cube(size=[20,1.6,300], center=true);

}


disc($winder_hei-0.2, label1=$label, label2="");


} // end module


module tiny_winder_side_B () {

difference () {
  translate([0,0,$box_hei/2])
  rcube(Size = [$box_len,$box_wid,2*$box_hei], b=10);

  translate([0,0,$box_hei/4])
  rcube(Size = [$box_len-6,$box_wid-6,3*$box_hei], b=10);

  // cutout
  //translate([0,0,$box_hei/2+17])
  //rcube(Size = [$box_len-4,$box_wid-4,3*$box_hei], b=8);

  translate([0,0,-$box_hei/2])
  cube(size=[2*$box_len,2*$box_wid,$box_hei], center=true);

  translate([0,0,$box_hei+$box_hei/2])
  cube(size=[2*$box_len,2*$box_wid,$box_hei], center=true);

  // Must be consistent with below ***
  // rg174
  translate([2,$box_wid/2.3,$winder_hei+2])
    rotate([-43,90,0])
      cylinder(h=40, r1=3.3/2, r2=3.3/2, center = true);

}

difference () {
  translate([0,0,$box_hei/2])
  rcube(Size = [$box_len-3.3,$box_wid-3.3,3.6*$box_hei], b=10);

  translate([0,0,$box_hei/4])
  rcube(Size = [$box_len-6,$box_wid-6,4*$box_hei], b=10);

  // vyrez
  //translate([0,0,$box_hei/2+17])
  //rcube(Size = [$box_len-4,$box_wid-4,3*$box_hei], b=8);

  translate([0,0,-$box_hei/2])
  cube(size=[2*$box_len,2*$box_wid,$box_hei], center=true);

  translate([0,0,$box_hei+$box_hei/2+5.6])
  cube(size=[2*$box_len,2*$box_wid,$box_hei], center=true);

  translate([0,0,$box_hei+2+$winder_hei])
    rotate([0,90,0])
      cylinder(h=100, r1=1.8/2, r2=1.8/2, center = true);

  translate([0,0,$box_hei+2+$winder_hei])
    rotate([90,90,0])
      cylinder(h=100, r1=1.8/2, r2=1.8/2, center = true);


  // Opening for Wire
  translate([0,-3,$box_hei+$winder_hei+0+10])
    rotate([0,90,0])
      cube(size=[20,1.6,$box_len+20], center=true);


  // Must be consistent with above ***
  // rg174
  translate([2,$box_wid/2.3,$winder_hei+2])
    rotate([-43,90,0])
      cylinder(h=40, r1=3.3/2, r2=3.3/2, center = true);

}

// Posts for fixing the RG-174 coad and fixing the toroid
translate([-10.0,-0.5,5.4]) cylinder(h=8,r1=3.2/2, r2=3.2/2, center = true);

translate([8.0,-0.5,5.4]) cylinder(h=8,r1=3.2/2, r2=3.2/2, center = true);

translate([0.5,$box_wid/2-7.2,3]) cylinder(h=6,r1=3.2/2, r2=3.2/2, center = true);
translate([-5.4,$box_wid/2-3.8,3]) cylinder(h=6,r1=3.2/2, r2=3.2/2, center = true);
translate([-1.0,$box_wid/2-12.2,4.20]) cylinder(h=4.6,r1=3.2/2, r2=3.2/2, center = true);


disc($winder_hei-0.2, label1="", label2=$label);

} // end module


//-----------------------------------------------------------------------
//-----------------------------------------------------------------------

// Side-A
translate([0, ($winder_len/2)/0.64,0])
  tiny_winder_side_A();

// Side-B
translate([0, (-$winder_len/2)/0.64,0])
  tiny_winder_side_B();


// Center disc with opening which have dimensions of inner_box
translate([$winder_len/1.7+$winder_wid,0,0]) 
rotate([0,0,90]) {
  difference() {
   disc($winder_hei, label1="", label2="");
   translate([0,0,$box_hei/2])
   rcube(Size = [$box_len-3.0,$box_wid-3.0,3*$box_hei], b=10);
  }
}

