//
// Insulators for lightweight shortwave linked-dipole.
// designed by Jan Uhrin, OM2JU, free to copy, modify
//

$fn = 32;

// Libraries:
//----------------------------------------------------------------------------------
//
// Rounded primitives for openscad
// (c) 2013 Wouter Robers 

// Syntax example for a rounded block
//translate([-15,0,10]) rcube([20,20,20],2);

// Syntax example for a rounded cylinder
//translate([15,0,10]) rcylinder(r1=15,r2=10,h=20,b=2);

module rcube(Size=[20,20,20],b=2)
{hull(){for(x=[-(Size[0]/2-b),(Size[0]/2-b)]){for(y=[-(Size[1]/2-b),(Size[1]/2-b)]){for(z=[-(Size[2]/2-b),(Size[2]/2-b)]){ translate([x,y,z]) sphere(b);}}}}}


module rcylinder(r1=10,r2=10,h=10,b=2)
{translate([0,0,-h/2]) hull(){rotate_extrude() translate([r1-b,b,0]) circle(r = b); rotate_extrude() translate([r2-b, h-b, 0]) circle(r = b);}}

//----------------------------------------------------------------------------------

module insulator ( label="17m") {
    
difference () {
union () {

// middle part of insulator
translate([0,0,2.0/2])
rcube(Size = [17,7.6,2.0], b=0.6);

// rounded end-1
translate([11-2.9,0,2.0/2])
rcylinder(h = 2.0, r1 = 8/2, r2 = 8/2, b=0.6);

// rounded end-2
translate([-11+2.9,0,2.0/2])
rcylinder(h = 2.0, r1 = 8/2, r2 = 8/2, b=0.6);

} // end union

$wd=1.9;
//
// holes through insulator
translate([12.5-2.5,0,0])  cylinder(h = 10, r1 = $wd/2, r2 = $wd/2, center = true);
translate([12.5-2.5,0,0])  cylinder(h = 3,  r1 = $wd/0.75, r2 = $wd/8, center = true);

translate([9.0-2.0,1.6,0])   cylinder(h = 10, r1 = $wd/2, r2 = $wd/2, center = true);
translate([9.0-2.0,1.6,0])   cylinder(h = 3,  r1 = $wd/0.75, r2 = $wd/8, center = true);

translate([9.0-2.0,-1.6,0])  cylinder(h = 10, r1 = $wd/2, r2 = $wd/2, center = true);
translate([9.0-2.0,-1.6,0])  cylinder(h = 3,  r1 = $wd/0.75, r2 = $wd/8, center = true);


translate([-12.5+2.5,0,0])  cylinder(h = 10, r1 = $wd/2, r2 = $wd/2, center = true);
translate([-12.5+2.5,0,0])  cylinder(h = 3,  r1 = $wd/0.75, r2 = $wd/8, center = true);

translate([-9.0+2.0,1.6,0])   cylinder(h = 10, r1 = $wd/2, r2 = $wd/2, center = true);
translate([-9.0+2.0,1.6,0])   cylinder(h = 3,  r1 = $wd/0.75, r2 = $wd/8, center = true);

translate([-9.0+2.0,-1.6,0])  cylinder(h = 10, r1 = $wd/2, r2 = $wd/2, center = true);
translate([-9.0+2.0,-1.6,0])  cylinder(h = 3,  r1 = $wd/0.75, r2 = $wd/8, center = true);

// label
rotate([0,0,0])
translate([ -5.6,-2.0,6.6-2.6]) linear_extrude (height=5, center = true) text(label, size=4.5, font="Courier:style=Bold");

//rotate([180,0,0])
//translate([ -7.2,-2.4,2.8-1]) linear_extrude (height=5, center = true) text(label, size=5.8, font="Courier:style=Bold");
} // end difference

} // end module

//-----------------------------------------------------------------------
//
// Place all insulators next to each other

translate([0,0*10, 0])  insulator(label="Kii");
//translate([0,1*10, 0])  insulator(label="Kii");
//translate([0,-1*10,0])  insulator(label="Kii");
//translate([0,2*10, 0])  insulator(label="Kii");
//translate([0,-2*10,0])  insulator(label="Kii");
//translate([0,3*10, 0])  insulator(label="Kii");



